using System.Windows;
using System.Windows.Controls.Primitives;
using System.Windows.Input;

namespace DynamicGridViewDemo
{
    public static class MouseLeftButtonUp
    {
        private static readonly DependencyProperty MouseLeftButtonUpCommandBehaviorProperty = DependencyProperty.RegisterAttached(
            "MouseLeftButtonUpCommandBehavior",
            typeof(MouseLeftButtonUpCommandBehavior),
            typeof(MouseLeftButtonUp),
            null);

        public static readonly DependencyProperty CommandProperty = DependencyProperty.RegisterAttached(
            "Command",
            typeof(ICommand),
            typeof(MouseLeftButtonUp),
            new PropertyMetadata(OnSetCommandCallback));

        public static readonly DependencyProperty CommandParameterProperty = DependencyProperty.RegisterAttached(
            "CommandParameter",
            typeof(object),
            typeof(MouseLeftButtonUp),
            new PropertyMetadata(OnSetCommandParameterCallback));

        public static void SetCommand(UIElement element, ICommand command)
        {
            element.SetValue(CommandProperty, command);
        }

        public static ICommand GetCommand(UIElement element)
        {
            return element.GetValue(CommandProperty) as ICommand;
        }

        private static void OnSetCommandCallback(DependencyObject dependencyObject, DependencyPropertyChangedEventArgs e)
        {
            UIElement element = dependencyObject as UIElement;
            if (element != null)
            {
                MouseLeftButtonUpCommandBehavior behavior = GetOrCreateBehavior(element);
                behavior.Command = e.NewValue as ICommand;
            }
        }

        public static void SetCommandParameter(ButtonBase buttonBase, object parameter)
        {
            buttonBase.SetValue(CommandParameterProperty, parameter);
        }

        public static object GetCommandParameter(ButtonBase buttonBase)
        {
            return buttonBase.GetValue(CommandParameterProperty);
        }

        private static void OnSetCommandParameterCallback(DependencyObject dependencyObject, DependencyPropertyChangedEventArgs e)
        {
            ButtonBase buttonBase = dependencyObject as ButtonBase;
            if (buttonBase != null)
            {
                MouseLeftButtonUpCommandBehavior behavior = GetOrCreateBehavior(buttonBase);
                behavior.CommandParameter = e.NewValue;
            }
        }

        private static MouseLeftButtonUpCommandBehavior GetOrCreateBehavior(UIElement element)
        {
            MouseLeftButtonUpCommandBehavior behavior = element.GetValue(MouseLeftButtonUpCommandBehaviorProperty) as MouseLeftButtonUpCommandBehavior;
            if (behavior == null)
            {
                behavior = new MouseLeftButtonUpCommandBehavior(element);
                element.SetValue(MouseLeftButtonUpCommandBehaviorProperty, behavior);
            }

            return behavior;
        }
    }
}