﻿using System;
using System.Linq;
using System.Collections.ObjectModel;
using System.ComponentModel;

using DynamicGridViewDemo.Entities;
using System.Windows.Input;
using Microsoft.Practices.Composite.Presentation.Commands;
using System.Windows;
using System.Collections.Generic;
using System.Windows.Resources;
using System.IO;

namespace DynamicGridViewDemo
{
    public class DynamicGridViewModel : INotifyPropertyChanged
    {
        ServiceReference1.Service1Client client = new DynamicGridViewDemo.ServiceReference1.Service1Client();

        public DynamicGridViewModel(string carriedNO)
        {
            MouseLeftButtonUpCommand = new DelegateCommand<MouseButtonEventArgs>(OnMouseLeftButtonUp);
      
            this.CarriedNO = carriedNO;

            client.RetrieveFlightListCompleted += client_RetrieveFlightListCompleted;
            client.RetrieveFlightListAsync(carriedNO);
        }

        void client_RetrieveFlightListCompleted(object sender, DynamicGridViewDemo.ServiceReference1.RetrieveFlightListCompletedEventArgs e)
        {
            var result = from item in e.Result
                         select new FlightInfo()
                         {
                             FlightNO = item.FlightNO,
                             Date = item.Date,
                             ORIG = item.ORIG,
                             DEST = item.DEST,
                             Remarks = item.Remarks,
                             AIOCO = item.AIOCO
                         };

            ObservableCollection<FlightInfo> fList = new ObservableCollection<FlightInfo>();
            result.ToList().ForEach(item => fList.Add(item));

            this.FlightList = fList;

            View.LoadMenu();

            this.SelectedFlightInfo = this.FlightList[0];
        }

        public void OnMouseLeftButtonUp(MouseButtonEventArgs e)
        {
            View.PopMenuByColumnID(e);
        }

        public DynamicGridView View { get; set; }
        public ICommand MouseLeftButtonUpCommand { get; set; }

        private string carriedNO;
        public string CarriedNO
        {
            get
            {
                return carriedNO;
            }

            set
            {
                if (carriedNO != value)
                {
                    carriedNO = value;
                    OnPropertyChanged("CarriedNO");
                }
            }
        }

        private FlightInfo selectedFlightInfo;
        public FlightInfo SelectedFlightInfo
        {
            get
            {
                return selectedFlightInfo;
            }

            set
            {
                if (selectedFlightInfo != value)
                {
                    selectedFlightInfo = value;
                    OnPropertyChanged("SelectedFlightInfo");
                }
            }
        }

        private ObservableCollection<FlightInfo> flightList;
        public ObservableCollection<FlightInfo> FlightList
        {
            get
            {
                return flightList;
            }

            set
            {
                if (flightList != value)
                {
                    flightList = value;
                    OnPropertyChanged("FlightList");
                }
            }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion
    }
}